coherence.upnp.devices.wan_connection_device_client (module) — Cohen3 0.8.0 documentation

# coherence.upnp.devices.wan_connection_device_client (module)

## `WANConnectionDeviceClient`

A class representing an WAN connection client device.

class `WANConnectionDeviceClient`(device)

  Bases: `eventdispatcher.eventdispatcher.EventDispatcher`, `coherence.log.LogAble`

  Changed in version 0.9.0:

  - Introduced inheritance from EventDispatcher

  - The emitted events changed:

    > - Coherence.UPnP.EmbeddedDeviceClient.detection_completed => embedded_device_client_detection_completed

  - Changed class variable `detection_completed` to benefit from the EventDispatcher’s properties

  `logCategory` = 'igd_client'
  `detection_completed`

    To know whenever the wan device detection has completed. Defaults to False and it will be set automatically to True by the class method `service_notified()`.

  `remove`()
  `service_notified`(service)